
/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */

package com.jsevy.jsvg;


import java.awt.geom.AffineTransform;

/**
 * Graphical entity representing a circular arc.
 * 
 * @author jsevy
 *
 */
class SVGCircle extends SVGEntity
{
    protected RealPoint center;
    protected double radius;
    
    
    /**
     * Create a circular arc from the specified parameters.
     * @param center		Center of the circle, as a RealPoint
     * @param radius		Radius of the circle
     * @param style			The ODGSTyle object specifying rendering parameters for the shape (color, thickness, etc.)
     */
    public SVGCircle(RealPoint center, double radius, SVGGraphicsStyle style)
    {
        this(center, radius, style, new AffineTransform());
    }
    
    
    /**
     * Create a circular arc from the specified parameters.
     * @param center        Center of the circle, as a RealPoint
     * @param radius        Radius of the circle
     * @param style         The ODGSTyle object specifying rendering parameters for the shape (color, thickness, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public SVGCircle(RealPoint center, double radius,SVGGraphicsStyle style, AffineTransform transform)
    {
        super(style, transform);
        
        this.center = center;
        this.radius = radius;
        
        populateXML();
    }
    
    /**
     * Populate XMLNode fields for XML generation
     */
    protected void populateXML()
    {
        this.setNodeName("circle");
        
        // add attributes
        this.setAttribute("cx", scaleValue(center.x));
        this.setAttribute("cy", scaleValue(center.y));
        this.setAttribute("r", scaleValue(radius));
        
        // add style attributes, and transform attribute if any
        super.populateXML();
        
    }
    
    
    
}