/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */


package com.jsevy.jsvg;



/**
 * Base class for styles, which indicate characteristics for rendering text or graphics.
 * @author jsevy
 *
 */
abstract class SVGStyle extends SVGObject
{
    protected String styleName;
    
    
    /**
     * Create a new style object, and get a unique name for it from the ODGStyles class.
     */
    public SVGStyle()
    {
        this.styleName = SVGStyles.getNextName();
        
        populateXML();
    }
    
    
    public String getStyleName()
    {
        return styleName;
    }
    
    
    /**
     * Used to see if the current list of Styles already contains a specified Style
     */
    public abstract boolean equals(Object other);
    
    
    
    
    /**
     * Populate XMLNode fields for XML generation
     */
    private void populateXML()
    {
        this.setNodeName("style");
    }
    
}
