/*
 * JSVG Library
 * 
 *   Copyright (C) 2020, Jonathan Sevy <jsevy@jsevy.com>
 *   
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *   of this software and associated documentation files (the "Software"), to deal
 *   in the Software without restriction, including without limitation the rights
 *   to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *   copies of the Software, and to permit persons to whom the Software is
 *   furnished to do so, subject to the following conditions:
 *   
 *   The above copyright notice and this permission notice shall be included in all
 *   copies or substantial portions of the Software.
 *   
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *   SOFTWARE.
 * 
 */

package com.jsevy.jsvg;


import java.awt.geom.AffineTransform;



/**
 * Class representing a box containing text, located at a specified position and having specified style (font, size).
 * 
 * @author jsevy
 *
 */
class SVGText extends SVGEntity
{
    private String text;
    double x, y;
    
    
    /**
     * Create a text object at the specified position.
     * 
     * @param text		    Text string
     * @param x             x coordinate for text baseline
     * @param y             y coordinate for text baseline
     * @param style         The SVTextGStyle object specifying rendering parameters for the text (color, font, etc.)
     * @param transform     Affine transform to be applied to the shape
     */
    public SVGText(String text, double x, double y, SVGTextStyle style, AffineTransform transform)
    {
        super(style, transform);
        
        this.text = text;
        this.x = x;
        this.y = y;
        
        populateXML();
    }
    
    /**
     * Populate XMLNode fields for XML generation
     */
    protected void populateXML()
    {
        // text-box is pretty much just a dummy container
        // all the action is in its child paragraph node
        this.setNodeName("text");
        
        this.setAttribute("x", scaleValue(x));
        this.setAttribute("y", scaleValue(y));
        
        // set text - adds a Text node as a child
        this.setTextContent(text);
        
        // add style attributes, and transform attribute if any
        super.populateXML();
        
    }
    
    
}