package com.jsevy.jxml;

import java.util.ArrayList;
import java.util.HashMap;

import org.w3c.dom.DOMException;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

public class XMLNamedNodeMap extends HashMap<XMLNamedNodeMap.XMLNamespaceName, Node> 
                                implements NamedNodeMap
{
    
    private static final long serialVersionUID = 1L;



    /**
     * Just a wrapper class for a String[2] array to serve as the Key for
     * the underlying HashMap, since we need to accomodate both a Node name _and_
     * possibly its namespce URI. But a String[2] array doesn't work as a HaspMap
     * key, because two different arrays containing the same strings will have different 
     * hashmaps. An ArrayList doesn't have this issue. Sigh... Luckily this is buried
     * in this class definition, so never exposed to the outside world.
     * @author jsevy
     *
     */
    protected class XMLNamespaceName extends ArrayList<String>
    {
        
        private static final long serialVersionUID = 1L;

        public XMLNamespaceName(String namespaceURI, String localName)
        {
            super();
            this.add(namespaceURI);
            this.add(localName);
        }
    }
    
    
    
    @Override
    public Node getNamedItem(String name)
    {
        // use "" for namespace instead of stupid null in spec
        XMLNamespaceName arg = new XMLNamespaceName("", name);
        return this.get(arg);
    }
    
    
    
    @Override
    public Node setNamedItem(Node newNode) throws DOMException
    {
        String name = newNode.getNodeName();
        Node oldNode = this.getNamedItem(name);
        
        if (oldNode == null)
        {
            // no named node currently; add
            // use "" for namespace instead of stupid null in spec
            XMLNamespaceName arg = new XMLNamespaceName("", name);
            this.put(arg, newNode);
        }
        else
        {
            // have a node with the given name; replace it
            // use "" for namespace instead of stupid null in spec
            XMLNamespaceName arg = new XMLNamespaceName("", name);
            this.replace(arg, newNode);
        }
        
        // return old node, or null if there was nothing mapped
        return oldNode;
    }
    
    
    
    @Override
    public Node removeNamedItem(String name) throws DOMException
    {
        // use "" for namespace instead of stupid null in spec        
        XMLNamespaceName arg = new XMLNamespaceName("", name);
        return this.remove(arg);
    }
    
    
    
    @Override
    public Node item(int index)
    {
        return (Node)this.values().toArray()[index];
    }
    
    
    
    @Override
    public int getLength()
    {
        return this.size();
    }
    
    
    
    @Override
    public Node getNamedItemNS(String namespaceURI, String localName) throws DOMException
    {
        // spec says use null if no namespace; change to "" to keep Map happy
        if (namespaceURI == null)
            namespaceURI = "";
                
        XMLNamespaceName arg = new XMLNamespaceName(namespaceURI, localName);
        Node namedItem = this.get(arg);
        
        return namedItem;
    }
    
    
    
    @Override
    public Node setNamedItemNS(Node newNode) throws DOMException
    {
        String namespaceURI = newNode.getNamespaceURI();
        String localName = newNode.getNodeName();
        
        // spec says use null if no namespace; change to "" to keep Map happy
        if (namespaceURI == null)
            namespaceURI = "";
                
        
        Node oldNode = this.getNamedItemNS(namespaceURI, localName);
        if (oldNode == null)
        {
            // no node currently with both namespace and name; add
            XMLNamespaceName arg = new XMLNamespaceName(namespaceURI, localName);
            this.put(arg, newNode);
        }
        else
        {
            // have a node with the given name and namespace; replace it
            XMLNamespaceName arg = new XMLNamespaceName(namespaceURI, localName);
            this.replace(arg, newNode);
        }
        
        // return old node, or null if there was nothing mapped
        return oldNode;
    }
    
    
    
    @Override
    public Node removeNamedItemNS(String namespaceURI, String localName) throws DOMException
    {
        // spec says use null if no namespace; change to "" to keep Map happy
        if (namespaceURI == null)
            namespaceURI = "";
        
        XMLNamespaceName arg = new XMLNamespaceName(namespaceURI, localName);
        return this.remove(arg);
    }
    
}
